@@ -72,7 +72,7 @@ class Rule:
 		min_length: int | None = None,
 		max_length: int | None = None,
 		regex: Pattern | None = None,
-		check_method: Callable = lambda x, *a: True,
+		check_method: Callable | None = None,
 		validator: Validator | None = None
 	):
 		if (min is not None or max is not None) and data_type not in (int, float):
@@ -99,6 +99,9 @@ class Rule:
 		self.__optional = optional
 		self.__min = min
 		self.__max = max
+		self.__length = length
+		self.__min_length = min_length
+		self.__max_length = max_length
 		self.__regex = regex
 		self.__check_method = check_method
 		self.__validator = validator
@@ -129,12 +132,15 @@ class Rule:
 		):
 			return False, ValidatorError.NUMBER_NOT_IN_RANGE, ""
 		elif (
-			(self.__length is not None and self.__lenght > len(value)) or  # type: ignore
+			(self.__length is not None and self.__length > len(value)) or  # type: ignore
 			(self.__min_length is not None and self.__min_length > len(value)) or  # type: ignore
 			(self.__max_length is not None and self.__max_length > len(value))  # type: ignore
 		):
 			return False, ValidatorError.NUMBER_NOT_IN_RANGE, ""
-		elif self.__regex and self.__regex.match(value) or self.__check_method(value):  # type: ignore
+		elif (
+			(self.__regex and not self.__regex.match(value)) or  # type: ignore
+			(self.__check_method and not self.__check_method(value))
+		):
 			return False, ValidatorError.INVALID_VALUE, ""
 		elif self.__validator:
 			self.__validator.check(value)  # type: ignore
@@ -185,11 +191,13 @@ class Rule:
 
 class RequestValidator(Validator):
 	def __init__(self, exact_keys: bool = False):
-		super().__call__(exact_keys)
+		super().__init__(exact_keys=exact_keys)
 
 	def __call__(self, method, *args, **kwargs):
+		call = super().__call__
+
 		async def wrapper(req, resp, *args, **kwargs):
-			result = super().__call__(req.data)
+			result = call(req.data)
 			if result[0]:
 				return await method(req, resp, *args, data=self, **kwargs)
 			else:
